##############################################################################
#
# Copyright (c) 2002 Ingeniweb SARL
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#
##############################################################################

"""
Plone Article core classes for images and attachments and layout models
"""

from AccessControl import ClassSecurityInfo
import string
import random
import os
from Products.CMFCore import CMFCorePermissions
from AccessControl import Permissions, getSecurityManager, ClassSecurityInfo, Unauthorized
from OFS import Folder, Image, ObjectManager
from Products.ZAttachmentAttribute import ZAttachmentAttribute
from global_symbols import ArticleCore_editPermission
from Products.CMFCore.utils import getToolByName
from Products.PloneNewsItem.Installation import Installation


#                                                                           #
#                           MODEL SUPPORT                                   #
#                                                                           #


class ArticleModel(ObjectManager.ObjectManager):

    security = ClassSecurityInfo()
    
    # Init method
    security.declarePrivate('__init__')
    def __init__(self):
        """__init__(self)"""
        self.model=''

    security.declarePrivate('_post_init')
    def _post_init(self):
        """
        _post_init(self) => Post-init method (that is, method that is called
                            AFTER the class has been set into the ZODB)
        """
        self.model=self._getDefaultModel()

    security.declareProtected(CMFCorePermissions.View, "getModel")
    def getModel(self):
        """
        getModel(self) => returns the Model of the PloneNewsItem
        """
        template=getattr(self, self.model, None)
        if template:
            model=self.model
        else:
            raise "Model does not exist"
        return model

    security.declareProtected(CMFCorePermissions.View, "getModelPath")
    def getModelPath(self):
        """
        getModelPath(self, model) => returns the path where the macro for
                                     the model can be found
        """
        # The path expression used in PloneNewsItem_view
        model_path='here/%(template)s/macros/%(macro)s'
        template=self.getModel()
        # The standard name for the macro is different for Plone 1 or 2
        macro='PloneNewsItemModel'
        if self._isPlone2():
            # Macro for Plone 2
            macro='Plone2NewsItemModel'
        return model_path % ({'template':template,'macro':macro})

    security.declareProtected(ArticleCore_editPermission, 'setModel')
    def setModel(self, model):
        """
        setModel(self) => sets the Model to serve as a layout for the PloneNewsItem
        """
        template=getattr(self, model, None)
        if template:
            self.model = model
        else:
            raise "Model does not exist"

    security.declareProtected(CMFCorePermissions.View, "getModelTitle")
    def getModelTitle(self, model):
        """
        getModelTitle(self) => returns the Model Title for the Model that serves as a layout for the PloneNewsItem
                               First takes the customized models and then falls back to the StockModels.
        """
        template=getattr(self, model, None)
        if template:
            modeltitle=template.title_or_id()
        else:
            raise "Template does not exist"
        return modeltitle

    def _getDefaultModel(self):
        """
        _getDefaultModel(self) => returns the default Model to serve as a layout for the PloneNewsItem
        """
        model = "PloneNewsItemModel2"
        if self._isPlone2():
            #If Plone 2, return the default model skin for Plone 2
            model = "PloneNewsItemModel2_2"
        return model

    security.declarePrivate('isPlone2')
    def _isPlone2(self,):
        portal_url = getToolByName(self, 'portal_url')
        if 'portal_form_controller' in portal_url.getPortalObject().objectIds():
            return 1
        return 0
